EXPORTS
	??0CMobilityConnectionProvider@@IAE@AAVCConnectionProviderFactoryBase@ESock@@ABUTNodeActivityMap@MeshMachine@@@Z @ 1 NONAME ; CMobilityConnectionProvider::CMobilityConnectionProvider(class ESock::CConnectionProviderFactoryBase &, struct MeshMachine::TNodeActivityMap const &)
	??0CMobilityMetaConnectionProvider@@IAE@AAVCMetaConnectionProviderFactoryBase@ESock@@ABVTProviderInfo@2@ABUTNodeActivityMap@MeshMachine@@@Z @ 2 NONAME ; CMobilityMetaConnectionProvider::CMobilityMetaConnectionProvider(class ESock::CMetaConnectionProviderFactoryBase &, class ESock::TProviderInfo const &, struct MeshMachine::TNodeActivityMap const &)
	??1CMobilityConnectionProvider@@MAE@XZ @ 3 NONAME ; CMobilityConnectionProvider::~CMobilityConnectionProvider(void)
	??1CMobilityMetaConnectionProvider@@UAE@XZ @ 4 NONAME ; CMobilityMetaConnectionProvider::~CMobilityMetaConnectionProvider(void)
	?CancelSubscription@CMobilityConnectionProvider@@EAEXI@Z @ 5 NONAME ; void CMobilityConnectionProvider::CancelSubscription(unsigned int)
	?CloseExtensionInterface@CMobilityConnectionProvider@@EAEXI@Z @ 6 NONAME ; void CMobilityConnectionProvider::CloseExtensionInterface(unsigned int)
	?IgnorePreferredCarrier@CMobilityConnectionProvider@@EAEXI@Z @ 7 NONAME ; void CMobilityConnectionProvider::IgnorePreferredCarrier(unsigned int)
	?MigrateToPreferredCarrier@CMobilityConnectionProvider@@EAEXI@Z @ 8 NONAME ; void CMobilityConnectionProvider::MigrateToPreferredCarrier(unsigned int)
	?NewCarrierAccepted@CMobilityConnectionProvider@@EAEXI@Z @ 9 NONAME ; void CMobilityConnectionProvider::NewCarrierAccepted(unsigned int)
	?NewCarrierRejected@CMobilityConnectionProvider@@EAEXI@Z @ 10 NONAME ; void CMobilityConnectionProvider::NewCarrierRejected(unsigned int)
	?NewL@CMobilityConnectionProvider@@SAPAV1@AAVCConnectionProviderFactoryBase@ESock@@ABUTNodeActivityMap@MeshMachine@@@Z @ 11 NONAME ; class CMobilityConnectionProvider * CMobilityConnectionProvider::NewL(class ESock::CConnectionProviderFactoryBase &, struct MeshMachine::TNodeActivityMap const &)
	?OpenExtensionInterface@CMobilityConnectionProvider@@EAEXIABVTRuntimeCtxId@Messages@@PAVCCommsApiExtResponder@ESock@@@Z @ 12 NONAME ; void CMobilityConnectionProvider::OpenExtensionInterface(unsigned int, class Messages::TRuntimeCtxId const &, class ESock::CCommsApiExtResponder *)
	?Received@CMobilityMetaConnectionProvider@@IAEXAAVTNodeContextBase@MeshMachine@@@Z @ 13 NONAME ; void CMobilityMetaConnectionProvider::Received(class MeshMachine::TNodeContextBase &)
	?ReceivedL@CMobilityConnectionProvider@@MAEXABVTRuntimeCtxId@Messages@@ABVTNodeId@3@AAVTSignatureBase@3@@Z @ 14 NONAME ; void CMobilityConnectionProvider::ReceivedL(class Messages::TRuntimeCtxId const &, class Messages::TNodeId const &, class Messages::TSignatureBase &)
	?ReturnInterfacePtrL@CMobilityConnectionProvider@@QAEXAAPAVAMobilityProtocolReq@ESock@@@Z @ 15 NONAME ; void CMobilityConnectionProvider::ReturnInterfacePtrL(class ESock::AMobilityProtocolReq * &)
	?Self@mobilityCprActivities@MobilityCprActivities@@SAABUTNodeActivityMap@MeshMachine@@XZ @ 16 NONAME ; struct MeshMachine::TNodeActivityMap const & MobilityCprActivities::mobilityCprActivities::Self(void)
	?Self@mobilityMCprActivities@MobilityMCprActivities@@SAABUTNodeActivityMap@MeshMachine@@XZ @ 17 NONAME ; struct MeshMachine::TNodeActivityMap const & MobilityMCprActivities::mobilityMCprActivities::Self(void)
	?SubscribeForMessage@CMobilityConnectionProvider@@EAEXIPAVCCommsMobilitySrvResp@@@Z @ 18 NONAME ; void CMobilityConnectionProvider::SubscribeForMessage(unsigned int, class CCommsMobilitySrvResp *)


